<?php
/**
 * Plugin Name: Display Current Product Category
 * Description: Display the current WooCommerce product category anywhere on your product template, using the <code>[get_current_product_category]</code> shortcode.
 * Version: 1.1
 * Author: Kornerstone Media
 * Author URI: https://www.kornerstonemedia.com
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.en.html
 * Domain Path: /languages
 * Text Domain: dcwcpc
 * 
 * WC requires at least: 4.0
 * WC tested up to: 6.5
 */

/*
   Copyright (C) 2022 Kornerstone Media

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

if ( ! defined( 'ABSPATH' ) ) { die( 'Forbidden' ); }

define( 'DCWCPC_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'DCWCPC_PLUGIN_URI', plugin_dir_url( __FILE__ ) );

class DisplayCurrentWCProductCategory {
  function __construct(){
    if( is_admin() ){
      add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );
    }
    add_shortcode( 'get_current_product_category', array( $this, 'shortcode_get_current_product_category' ) );
  }

  /**
   * Load plugin text domain
   * 
   * @since 1.0
   */
  public static function load_textdomain(){
    load_plugin_textdomain( 'dcwcpc', false, basename( DCWCPC_PLUGIN_DIR ) . '/languages' );
  }

  /**
   * [get_current_product_category] shortcode
   * 
   * @param	array	$atts			Array of attributes
   * @param	string $content	Content of the shortcode
   * @since 1.0
   */
  public static function shortcode_get_current_product_category( $atts, $content = null ){
    $atts = shortcode_atts(
      array(
          'linked' => 'false',
      ), $atts, 'get_current_product_category' );

    global $post;
    $terms = get_the_terms( $post->ID, 'product_cat' );
    foreach ($terms as $term ) {
      if( $atts['linked'] === 'true' ){
        $product_cat_name = '<a href="' . esc_url( get_term_link( $term ) ) . '">' . $term->name . '</a>';
      } else {
        $product_cat_name = $term->name;
      }
      break;
    }
    return $product_cat_name;
  }

}

// Check if WooCommerce exists
$plugin_path = trailingslashit( WP_PLUGIN_DIR ) . 'woocommerce/woocommerce.php';

if ( in_array( $plugin_path, wp_get_active_and_valid_plugins() ) || in_array( $plugin_path, wp_get_active_network_plugins() )) {
  $DisplayCurrentWCProductCategory = new DisplayCurrentWCProductCategory();
}
